<?php

namespace Drupal\Tests\media_library_media_modify\FunctionalJavascript;

use Drupal\Tests\media_library\FunctionalJavascript\MediaLibraryTestBase;
use Drupal\views\Views;
use Drupal\media\Entity\Media;
use Drupal\Tests\TestFileCreationTrait;
use Drupal\file\Entity\File;

/**
 * Test the views edit link in the media library.
 *
 * @group media_library_media_modify
 */
class MediaLibraryMediaModifyEditLinkTest extends MediaLibraryTestBase {

  use TestFileCreationTrait;

  /**
   * The media item to work with.
   *
   * @var \Drupal\media\MediaInterface
   */
  protected $media;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['media_library_media_modify'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $image = File::create([
      'uri' => $this->getTestFiles('image')[0]->uri,
    ]);
    $image->setPermanent();
    $image->save();

    $this->media = Media::create([
      'bundle' => 'type_three',
      'name' => 'Disturbing',
      'field_media_test_image' => [
        ['target_id' => $image->id()],
      ],
    ]);
    $this->media->save();

    // Create a user who can use the Media library.
    $user = $this->drupalCreateUser([
      'access content',
      'create basic_page content',
      'edit own basic_page content',
      'view media',
      'create media',
      'administer media',
      'update any media',
      'update media',
    ]);
    $this->drupalLogin($user);
  }

  /**
   * Test the edit link in media form.
   */
  public function testEditLink() {

    $view = Views::getView('media_library');
    $view->setDisplay('widget');

    $fields = $view->displayHandlers->get('widget')->getOption('fields');

    $fields['media_library_media_modify_edit_link'] = [
      'id' => 'media_library_media_modify_edit_link',
      'table' => 'media',
      'field' => 'media_library_media_modify_edit_link',
      'relationship' => 'none',
    ];

    $view->displayHandlers->get('widget')->overrideOption('fields', $fields);
    $view->save();

    $assert_session = $this->assertSession();
    $page = $this->getSession()->getPage();

    // Visit a node create page.
    $this->drupalGet('node/add/basic_page');

    $this->openMediaLibraryForField('field_unlimited_media');
    $this->switchToMediaType('Three');
    $this->assertNotEmpty($assert_session->waitForText('Showing Type Three media.'));

    // Select the item.
    $checkboxes = $this->getCheckboxes();
    $checkboxes[0]->click();

    // Edit the item.
    $page->pressButton('media_library_media_modify_edit_link-0');
    $assert_session->assertWaitOnAjaxRequest();
    $page->fillField('media[0][fields][field_media_test_image][0][alt]', 'My alt text');
    $this->pressSaveButton();
    $assert_session->assertWaitOnAjaxRequest();

    // Check item is still selected.
    $assert_session->checkboxChecked('media_library_select_form[0]');

    $media = Media::load($this->media->id());
    $this->assertEquals('My alt text', $media->field_media_test_image->alt);
  }

}
